//
//  YHAutoTextView.swift
//  galaxy
//
//  Created by Dufet on 2024/11/20.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHAutoTextView: UITextView, UITextViewDelegate {
    
    override open var text: String! {
        didSet {
            self.setNeedsLayout()
            self.layoutIfNeeded()
        }
    }

    var placeHolder: String = "" {
        didSet {
            placeholderLabel.text = placeHolder
        }
    }

    let placeholderLabel: UILabel = {
        let label = UILabel()
        label.translatesAutoresizingMaskIntoConstraints = false
        label.textColor = UIColor.lightGray
        label.font = UIFont.PFSC_R(ofSize: 15)
        return label
    }()

    override init(frame: CGRect, textContainer: NSTextContainer?) {
        super.init(frame: frame, textContainer: textContainer)
        delegate = self
        isScrollEnabled = false // 禁止滚动
        translatesAutoresizingMaskIntoConstraints = false
        clearsOnInsertion = true
        
        self.addSubview(placeholderLabel)
        placeholderLabel.snp.makeConstraints { make in
            make.top.equalTo(5)
            make.left.equalTo(5)
            make.right.equalTo(-5)
        }
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    // UITextViewDelegate 方法
    func textViewDidChange(_ textView: UITextView) {
        // 更新自身的高度
        invalidateIntrinsicContentSize()
        placeholderLabel.isHidden = !textView.text.isEmpty
    }

    override var intrinsicContentSize: CGSize {
        // 计算内容的尺寸
        let size = sizeThatFits(CGSize(width: frame.width, height: .greatestFiniteMagnitude))
        return CGSize(width: size.width, height: size.height)
    }
}
