//
//  YHHomeIdentityViewController.swift
//  galaxy
//
//  Created by edy on 2024/7/18.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import JXSegmentedView

class YHHomeIdentityViewController: YHBaseViewController {
    
    var subTabArr:[YHHomeLifeCategoryModel] = []
    
    var sectionView: YHSelectLookView!
    var tableView: UITableView!
    var headView: YHSelectLookHeadView!
    
    lazy var viewModel: YHHomePageViewModel = {
        let vm = YHHomePageViewModel()
        return vm
    }()
    
    lazy var subTabBar: YHIdentityTabBar = {
        let bar = YHIdentityTabBar.tabBarForItems([])
        bar.selectBlock = {
            [weak self] index, item in
            guard let self = self else { return }
            self.scrollView.setContentOffset(CGPointMake(KScreenWidth * Double(index), 0), animated: false)
            if 0 <= index, index < self.children.count {
                let vc = self.children[index]
                if vc.isKind(of: YHHomeIdentityListVC.self) {
                    (vc as! YHHomeIdentityListVC).isShowBottomView = false
                    self.hideBottomOnTabbar()
                }
            }
        }
        return bar
    }()
    
    lazy var scrollView:UIScrollView = {
        let view = UIScrollView()
        view.isScrollEnabled = false
        return view
    }()
    
    lazy var noDataView: YHEmptyDataView = {
        let view = YHEmptyDataView.createView("暂无内容", kEmptyCommonBgName)
        view.backgroundColor = .white
        view.topMargin = 150
        view.isHidden = true
        return view
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        createUI()
        loadData()
    }
    
    func createUI() {
        gk_navigationBar.isHidden = true
        self.view.backgroundColor = .white

        self.view.addSubview(self.scrollView)
        self.view.addSubview(self.subTabBar)
        self.view.addSubview(self.noDataView)
        
        self.subTabBar.snp.makeConstraints { make in
            make.top.equalToSuperview()
            make.left.equalTo(20)
            make.right.equalTo(-20)
            make.height.equalTo(44)
        }
        self.scrollView.snp.makeConstraints { make in
            make.top.equalTo(self.subTabBar.snp.bottom)
            make.left.right.bottom.equalToSuperview()
        }
        
        self.noDataView.snp.makeConstraints { make in
            make.left.right.top.bottom.equalToSuperview()
        }
        
        scrollView.isHidden = true
        subTabBar.isHidden = true
        
        sectionView = {
            let view = YHSelectLookView()
            view.block = {[weak self] itemIndex in
                guard let self = self else { return }
            }
            return view
        }()
        sectionView.frame = CGRect(x: 0, y: 0, width: KScreenWidth, height: 92)
        headView = {
            let head = YHSelectLookHeadView()
            head.frame = CGRect(x: 0, y: 0, width: KScreenWidth, height: 46)
            return head
        }()
        
        tableView = {
            let tableView = UITableView(frame: .zero, style: .grouped)
            tableView.contentInsetAdjustmentBehavior = .never
            tableView.backgroundColor = .white
            tableView.separatorStyle = .none
            tableView.showsHorizontalScrollIndicator = false
            tableView.showsVerticalScrollIndicator = false
            tableView.dataSource = self
            tableView.delegate = self
            tableView.tableHeaderView = sectionView
            tableView.tableFooterView = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 0.01))
            tableView.register(cellWithClass: YHSelectLookTableViewCell.self)
            return tableView
        }()
        view.addSubview(tableView)
        tableView.snp.makeConstraints { make in
            make.top.left.right.bottom.equalToSuperview()
        }
        
//        tableView.es.addYHPullToRefresh {
//            self.loadData()
//        }
         
        view.addSubview(noDataView)
        noDataView.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.centerY.equalToSuperview()
            make.width.equalTo(KScreenWidth)
            make.height.equalTo(150)
        }
        
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        hideBottomOnTabbar()
    }
    
    func hideBottomOnTabbar() {
        //隐藏
        var model = TabBarShareModel()
        model.showFlag = false
        NotificationCenter.default.post(name: YhConstant.YhNotification.changeShareViewStatusOnTabBarNotifiction, object: model)
    }
}

extension YHHomeIdentityViewController: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return 10
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withClass: YHSelectLookTableViewCell.self)
//        cell.dataSource = self.viewModel.detailModel.products[indexPath.row]
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return 120
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 46
    }

    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        return headView
    }

    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0.01
    }

    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
       
    }
}


extension YHHomeIdentityViewController: JXSegmentedListContainerViewListDelegate {
    func listView() -> UIView {
        return view
    }
}

extension YHHomeIdentityViewController {
    
    func loadData() {
        let params : [String : Any] = ["pid" : 2]
        self.viewModel.getGoodsCategory(params: params) {
            [weak self] success, error in
            
            self?.scrollView.es.stopPullToRefresh()
            
            guard let self = self else { return }
            
            if !success {
                self.view.bringSubviewToFront(self.noDataView)
                self.noDataView.isHidden = false
            }
            
            subTabArr.removeAll()
            for item in self.viewModel.categoryArr {
                if let item = item {
                    subTabArr.append(item)
                }
            }
            self.subTabBar.updateItems(subTabArr)
            
            self.scrollView.removeSubviews()
            for (index, item) in subTabArr.enumerated() {
                let vc = YHHomeIdentityListVC()
                vc.detailId = item.id
                vc.view.frame = CGRect(x: KScreenWidth * Double(index), y: 0, width: KScreenWidth, height: self.scrollView.height)
                vc.loadData()
                self.addChild(vc)
                self.scrollView.addSubview(vc.view)
            }
            self.scrollView.contentSize = CGSize(width: KScreenWidth * Double(self.subTabArr.count), height: self.scrollView.height)
        }
    }
}


