//
//  YHLivePlayerViewController.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/25.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import AgoraRtcKit
import UIKit

class YHLivePlayerViewController: YHBasePlayerViewController {
    // MARK: - Properties
    //private var roomInfo: YHLiveRoomInfo
    
    private var listMaxWidth: CGFloat {
        return KScreenWidth * 248.0 / 375.0
    }
    
    private lazy var bottomInputBar: YHInputBottomBar = {
        let view = YHInputBottomBar()
        view.textViewTappedEvent = { [weak self] in
            guard let self = self else {
                return
            }
            self.present(self.inputVC, animated: false)
        }
        return view
    }()
    
    private lazy var inputVC: YHMessageInputViewController = {
        let ctl = YHMessageInputViewController()
        ctl.closeCallbcak = {
            //
        }
        ctl.inputCallback = { [weak self] controller, text in
            //
        }
        return ctl
    }()
    
    private lazy var messageListView: YHLiveMessageListView = {
        let view = YHLiveMessageListView(frame: CGRect.init(x: 0, y: 0, width: listMaxWidth, height: listMaxWidth))
        return view
    }()
    
    let viewModel = YHLiveSalesViewModel()
    
    // MARK: - Initialization
    private let liveId: Int
    init(id: Int) {
        self.liveId = id
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    // MARK: - Lifecycle
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        requestData(id: liveId) { [weak self] liveDetail, error in
            guard let self = self else {
                return
            }
            guard let liveDetail = liveDetail else {
                printLog("YHLivePlayerViewController:  请求失败")
                if let errorMsg = error?.errorMsg, errorMsg.count > 0 {
                    YHHUD.flash(message: errorMsg)
                }
                return
            }
            self.topBarView.setupTopBarView(headUrl: liveDetail.avatar, nickname: liveDetail.hxNickname, count: liveDetail.access_num)
            self.play(with: liveDetail.pullUrl)
        }
    }
    
    // MARK: - Setup
    
    private func setupUI() {
        containerView.addSubview(bottomInputBar)
        containerView.addSubview(messageListView)
        
        bottomInputBar.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.top.equalTo(view.safeAreaLayoutGuide.snp.bottom).offset(-YHInputBottomBar.inputActionHeight)
        }
        
        messageListView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.bottom.equalTo(bottomInputBar.snp.top).offset(-14)
            make.height.width.equalTo(listMaxWidth)
        }
    }
    
    // MARK: - Player Control
    private func play(with url: String) {
        let mediaSource = AgoraMediaSource()
        mediaSource.url = url
        mediaSource.autoPlay = true
        
        let result = playerKit.open(with: mediaSource)
        if result != 0 {
            showAlert(message: "播放失败，错误码：\(result)")
        }
    }
}

extension YHLivePlayerViewController {
    override func AgoraRtcMediaPlayer(_ playerKit: AgoraRtcMediaPlayerProtocol,
                                     didChangedTo state: AgoraMediaPlayerState,
                                     reason: AgoraMediaPlayerReason) {
        super.AgoraRtcMediaPlayer(playerKit, didChangedTo: state, reason: reason)
        
        // 添加直播特定的状态处理
        switch state {
        case .playing:
            // 直播开始时的特殊处理
            break
        case .stopped:
            // 直播结束时的特殊处理
            break
        default:
            break
        }
    }
}
