//
//  YHLiveMessageListView.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/25.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHLiveMessageListView: UIView {
    private var messages: [YHLiveMessage] = []
    // MARK: - UI Components
    
    private lazy var topFadeView: YHFadeView = {
        let view = YHFadeView()
        view.backgroundColor = .clear.withAlphaComponent(0.1)
        return view
    }()

    private lazy var tableView: UITableView = {
        let view = UITableView()
        view.backgroundColor = .clear
        view.separatorStyle = .none
        view.showsVerticalScrollIndicator = false
        view.allowsSelection = false
        view.delegate = self
        view.dataSource = self
        view.transform = CGAffineTransform(rotationAngle: .pi)
        view.register(YHLiveMessageCell.self, forCellReuseIdentifier: YHLiveMessageCell.reuseIdentifier)
        return view
    }()

    // MARK: - Initialization

    override init(frame: CGRect) {
        super.init(frame: frame)
        setupUI()
        setupData()
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    private func setupData() {
        let message6 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "MAKESIBIB", level: 0, isAdmin: false), content: "优才今年政策", timestamp: Date())
        let message5 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "MAKESIBIB", level: 0, isAdmin: false), content: "😊", timestamp: Date())
        let message4 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "姑息可", level: 0, isAdmin: false), content: "优才申请时间有什么限制吗", timestamp: Date())
        let message3 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "侯米儿", level: 0, isAdmin: false), content: "我来了", timestamp: Date())
        let message2 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "奇思幻想牛先生", level: 0, isAdmin: false), content: "可以帮忙介绍一下香港优秀人才计划吗？", timestamp: Date())
        let message1 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "侯米儿", level: 0, isAdmin: false), content: "我工作5年，香港高才怎么申请更快获批啊", timestamp: Date())
        let message0 = YHLiveMessage.init(type: .normal, sender: YHLiveUser.init(userId: "1233", nickname: "谷溪", level: 0, isAdmin: false), content: "想了解香港教育有什么优势", timestamp: Date())
        messages = [message0, message1, message2, message3, message4, message5, message6]
//        messages = [message6]
        tableView.reloadData()
    }

    private func setupUI() {
        backgroundColor = .clear
        addSubview(tableView)
        addSubview(topFadeView)
        bringSubviewToFront(topFadeView)
        topFadeView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(26)
        }

        tableView.snp.makeConstraints { make in
            make.top.equalToSuperview()
            make.left.bottom.right.equalToSuperview()
        }
    }

    // MARK: - Public Methods

    func addMessage(_ message: YHLiveMessage) {
        messages.insert(message, at: 0)
        let indexPath = IndexPath(row: 0, section: 0)
        tableView.insertRows(at: [indexPath], with: .bottom)
    }

    func clearMessages() {
        messages.removeAll()
        tableView.reloadData()
    }
}

// MARK: - UITableViewDelegate & UITableViewDataSource

extension YHLiveMessageListView: UITableViewDelegate, UITableViewDataSource {
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return messages.count
    }

    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        guard messages.count > indexPath.row else {
            return UITableViewCell()
        }
        guard let cell = tableView.dequeueReusableCell(
            withIdentifier: YHLiveMessageCell.reuseIdentifier) as? YHLiveMessageCell else {
            return UITableViewCell()
        }
        let message = messages[indexPath.row]
        // cell 也需要旋转
        cell.contentView.transform = CGAffineTransform(rotationAngle: .pi)
        cell.configureNormalMessage(message.sender.nickname, message.content)
        return cell
    }
}
