//
//  YHLiveSalesViewModel.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/27.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHLiveSalesViewModel: YHBaseViewModel {
    // 直播间详情
    var liveDetailModel: YHLiveDetailModel?
    // 录播详情
    var recordedDetailModel: YHRecordedDetailModel?

    // 注册环信用户信息
    var huanXinUserInfoModel: YHHuanXinUserModel?
    
    // 获取环信Token信息
    var huanXinTokenModel: YHHuanXinTokenModel?
}

extension YHLiveSalesViewModel {
    /*
     注册环信用户
     */
    func registerHuanXinUser(callBackBlock: @escaping (_ success: Bool, _ error: YHErrorModel?) -> Void) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.LiveSales.registerHuanXinUserApi
        _ = YHNetRequest.postRequest(url: strUrl) { json, _ in
            // 1. json字符串 转 对象
            printLog("model 是 ==> \(json)")

            if json.code == 200 {
                guard let dic = json.data?.peel as? [String: Any], let resultModel = YHHuanXinUserModel.deserialize(from: dic) else {
                    let err = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    callBackBlock(false, err)
                    return
                }
                self.huanXinUserInfoModel = resultModel
                callBackBlock(true, nil)

            } else {
                let err = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg.isEmpty ? "" : json.msg)
                callBackBlock(false, err)
            }

        } failBlock: { err in
            callBackBlock(false, err)
        }
    }
    
    /*
     环信Token信息
     */
    func getHuanXinToken(callback: @escaping (_ tokenModel: YHHuanXinTokenModel?, _ error: YHErrorModel?) -> Void) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.LiveSales.fetchHuanXinToken
        _ = YHNetRequest.getRequest(url: strUrl, params: [:]) { [weak self] json, _ in
            // 1. json字符串 转 对象
            printLog("model 是 ==> \(json)")

            if json.code == 200 {
                guard let dic = json.data?.peel as? [String: Any], let resultModel = YHHuanXinTokenModel.deserialize(from: dic) else {
                    let err = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    callback(nil, err)
                    return
                }
                self?.huanXinTokenModel = resultModel
                callback(resultModel, nil)

            } else {
                let err = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg.isEmpty ? "" : json.msg)
                callback(nil, err)
            }

        } failBlock: { err in
            callback(nil, err)
        }
    }

    /*
     直播间详情
     */
    func getLiveDetail(id: Int, callback: @escaping (_ liveDetail: YHLiveDetailModel?, _ error: YHErrorModel?) -> Void) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.LiveSales.liveDetail
        _ = YHNetRequest.getRequest(url: strUrl, params: ["id": id]) { [weak self] json, _ in
            // 1. json字符串 转 对象
            printLog("model 是 ==> \(json)")

            if json.code == 200 {
                guard let dic = json.data?.peel as? [String: Any], let resultModel = YHLiveDetailModel.deserialize(from: dic) else {
                    let err = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    callback(nil, err)
                    return
                }
                self?.liveDetailModel = resultModel
                callback(resultModel, nil)

            } else {
                let err = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg.isEmpty ? "" : json.msg)
                callback(nil, err)
            }

        } failBlock: { err in
            callback(nil, err)
        }
    }
    
    /*
     点播详情
     */
    func getRecordedDetail(id: Int, callback: @escaping (_ recordedDetail: YHRecordedDetailModel?, _ error: YHErrorModel?) -> Void) {
        let strUrl = YHBaseUrlManager.shared.curURL() + YHAllApiName.LiveSales.recordedDetail
        _ = YHNetRequest.getRequest(url: strUrl, params: ["id": id]) { [weak self] json, _ in
            // 1. json字符串 转 对象
            printLog("model 是 ==> \(json)")

            if json.code == 200 {
                guard let dic = json.data?.peel as? [String: Any], let resultModel = YHRecordedDetailModel.deserialize(from: dic) else {
                    let err = YHErrorModel(errorCode: YHErrorCode.dictParseError.rawValue, errorMsg: YHErrorCode.dictParseError.description())
                    callback(nil, err)
                    return
                }
                self?.recordedDetailModel = resultModel
                callback(resultModel, nil)

            } else {
                let err = YHErrorModel(errorCode: Int32(json.code), errorMsg: json.msg.isEmpty ? "" : json.msg)
                callback(nil, err)
            }

        } failBlock: { err in
            callback(nil, err)
        }
    }
}
